@@ -10,33 +10,33 @@ Interchange6::Schema::Result::Inventory
 
 use Interchange6::Schema::Candy;
 
+=head1 DESCRIPTION
+
+The Inventory class is used to store current stock levels for products.
+
 =head1 ACCESSORS
 
 =head2 sku
 
-  data_type: 'varchar'
-  is_foreign_key: 1
-  is_nullable: 0
-  size: 64
-  primary key
+The SKU of the product.
+
+Primary key and foreign constraint on
+L<Interchange6::Schema::Result::Product/sku> via L</product> relationship.
 
 =cut
 
 primary_column sku =>
-  { data_type => "varchar", is_foreign_key => 1, is_nullable => 0, size => 64 };
+  { data_type => "varchar", is_foreign_key => 1, size => 64 };
 
 =head2 quantity
 
 This is the quantity currently held in stock.
 
-  data_type: 'integer'
-  default_value: 0
-  is_nullable: 0
+Defaults to 0.
 
 =cut
 
-column quantity =>
-  { data_type => "integer", default_value => 0, is_nullable => 0 };
+column quantity => { data_type => "integer", default_value => 0 };
 
 =head1 RELATIONS
 
